==> healthrian_common_support-1.18.0.tar.gz: lib/src/filter/deprecated/data_filter.dart <==
// ignore_for_file: public_member_api_docs, always_use_package_imports, non_constant_identifier_names, lines_longer_than_80_chars, avoid_positional_boolean_parameters, unused_element, use_setters_to_change_properties

import 'package:healthrian_common_support/healthrian_common_support.dart';
import 'package:healthrian_common_support/src/filter/deprecated/iir_filter/iir_filter.dart';
import 'package:healthrian_common_support/src/filter/deprecated/lib_constants.dart';
import 'package:healthrian_common_support/src/heartbeat/adaptive_filter.dart';

class DataFilter {
  DataFilter({
    required this.highPass_01,
    required this.highPass_05,
    required this.highPass_005,
    required this.lowPass_40,
    required this.lowPass_100,
    required this.bandStop_50,
    required this.bandStop_60,
    required this.dc_block_filter,
    required this.dc_block_filter_001,
    required this.adaptive,
    required this.flag_IIR_HPF_01,
    required this.flag_IIR_HPF_005,
    required this.flag_IIR_LPF_40,
    required this.flag_IIR_LPF_100,
    required this.flag_IIR_BSF_50,
    required this.flag_IIR_BSF_60,
    required this.flag_adaptive,
  });

  DataFilter.initialize(int channel) {
    highPass_005 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_HPF_0_05));
    highPass_01 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_HPF_0_1));
    highPass_05 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_HPF_0_5));
    lowPass_40 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_LPF_40));
    lowPass_100 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_LPF_100));
    bandStop_50 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_BSF_50));
    bandStop_60 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_BSF_60));

    dc_block_filter = List<DigitalFilter>.generate(
        channel, (i) => DigitalFilter());
    dc_block_filter_001 = List<DigitalFilter>.generate(
        channel, (i) => DigitalFilter());

    adaptive = List<AdaptiveFilterRT>.generate(
        channel, (index) => AdaptiveFilterRT.initialize());

    setDefaultFilterFlag();
  }

  late List<IIRFilterClass> highPass_01;
  late List<IIRFilterClass> highPass_05;
  late List<IIRFilterClass> highPass_005;
  late List<IIRFilterClass> lowPass_40;
  late List<IIRFilterClass> lowPass_100;
  late List<IIRFilterClass> bandStop_50;
  late List<IIRFilterClass> bandStop_60;

  late List<DigitalFilter> dc_block_filter;
  late List<DigitalFilter> dc_block_filter_001;

  /// adaptive filters
  late List<AdaptiveFilterRT> adaptive;

  /// fir filter
  // late List<FIRFilter>

  late bool flag_IIR_HPF_01;
  late bool flag_IIR_HPF_005;
  late bool flag_IIR_LPF_40;
  late bool flag_IIR_LPF_100;
  late bool flag_IIR_BSF_50;
  late bool flag_IIR_BSF_60;

  late bool flag_DC_BLOCK;

  /// flag for adaptive filter
  late bool flag_adaptive;

  void setDefaultFilterFlag() {
    /// Dc block
    flag_DC_BLOCK = true;

    /// High pass
    flag_IIR_HPF_01 = true;
    flag_IIR_HPF_005 = false;

    /// Low pass
    flag_IIR_LPF_40 = false;
    flag_IIR_LPF_100 = true;

    /// Band stop
    flag_IIR_BSF_50 = false;
    flag_IIR_BSF_60 = true;

    /// adaptive
    flag_adaptive = false;
  }

  void setFlagDcBlock({bool isDcBlock = true}) {
    flag_DC_BLOCK = isDcBlock;
  }

  void setFlagAdaptive({
    bool flagAdaptiveFilter = false,
  }) {
    flag_adaptive = flagAdaptiveFilter;
  }

  void setFlagHighPass({
    bool isHRF01 = true,
    bool isHRF005 = false,
  }) {
    flag_IIR_HPF_01 = isHRF01;
    flag_IIR_HPF_005 = isHRF005;
  }

  void setFlagLowPass({
    bool isLPF40 = false,
    bool isLPF100 = true,
  }) {
    flag_IIR_LPF_40 = isLPF40;
    flag_IIR_LPF_100 = isLPF100;
  }

  void setFlagBandStop({
    bool isBSF50 = false,
    bool isBSF60 = true,
  }) {
    flag_IIR_BSF_50 = isBSF50;
    flag_IIR_BSF_60 = isBSF60;
  }

  void setFlagEnable(
    String HighPass,
    String LowPass,
    String BandStop,
  ) {
    switch (HighPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_01:
        flag_IIR_HPF_01 = true;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_005:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = true;
        break;
    }
    switch (LowPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_40:
        flag_IIR_LPF_40 = true;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_100:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = true;
        break;
    }

    switch (BandStop) {
      case lib_constants.FILTER_NONE:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_50:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_60:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = true;
        break;
      case lib_constants.FILTER_BAND_STOP_50_60:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = true;
        break;
    }
  }

  double applyFilter(
    int channel,
    double resultData,
    bool leadState,
  ) {
    var filterResultData = resultData;
    if (leadState) {
      if (flag_DC_BLOCK) {
        // filterResultData =
            // dc_block_filter[channel].applyWithDouble(filterResultData);
      }

      if (flag_IIR_HPF_01) {
        filterResultData = highPass_01[channel].apply(filterResultData);
      }
      if (flag_IIR_HPF_005) {
        filterResultData = highPass_005[channel].apply(filterResultData);
      }

      if (flag_IIR_LPF_40) {
        filterResultData = lowPass_40[channel].apply(filterResultData);
      }
      if (flag_IIR_LPF_100) {
        filterResultData = lowPass_100[channel].apply(filterResultData);
      }

      if (flag_IIR_BSF_50) {
        filterResultData = bandStop_50[channel].apply(filterResultData);
      }
      if (flag_IIR_BSF_60) {
        filterResultData = bandStop_60[channel].apply(filterResultData);
      }

      if (flag_adaptive) {
        filterResultData = adaptive[channel].applyFilter(filterResultData);
      }
    }

    return filterResultData;
  }

  bool _isFilterApply() {
    return (flag_IIR_HPF_01 || flag_IIR_HPF_005) ||
        (flag_IIR_LPF_40 || flag_IIR_LPF_100) ||
        (flag_IIR_BSF_50 || flag_IIR_BSF_60);
  }
}

==> healthrian_common_support-1.31.4.tar.gz: lib/src/filter/deprecated/data_filter.dart <==
// ignore_for_file: public_member_api_docs, always_use_package_imports, non_constant_identifier_names, lines_longer_than_80_chars, avoid_positional_boolean_parameters, unused_element, use_setters_to_change_properties

import 'package:healthrian_common_support/healthrian_common_support.dart';
import 'package:healthrian_common_support/src/filter/deprecated/iir_filter/iir_filter.dart';
import 'package:healthrian_common_support/src/filter/deprecated/lib_constants.dart';
import 'package:healthrian_common_support/src/heartbeat/adaptive_filter.dart';

class DataFilter {
  DataFilter({
    required this.highPass_01,
    required this.highPass_05,
    required this.highPass_005,
    required this.lowPass_40,
    required this.lowPass_100,
    required this.bandStop_50,
    required this.bandStop_60,
    required this.dc_block_filter,
    required this.dc_block_filter_001,
    required this.adaptive,
    required this.flag_IIR_HPF_01,
    required this.flag_IIR_HPF_005,
    required this.flag_IIR_LPF_40,
    required this.flag_IIR_LPF_100,
    required this.flag_IIR_BSF_50,
    required this.flag_IIR_BSF_60,
    required this.flag_adaptive,
  });

  DataFilter.initialize(int channel) {
    highPass_005 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_HPF_0_05));
    highPass_01 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_HPF_0_1));
    highPass_05 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_HPF_0_5));
    lowPass_40 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_LPF_40));
    lowPass_100 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_LPF_100));
    bandStop_50 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_BSF_50));
    bandStop_60 = List.generate(
        channel, (i) => IIRFilterClass.initialize(IIRConstant.IIR_BSF_60));

    dc_block_filter = List<DcNotch>.generate(
        channel, (i) => DcNotch());
    dc_block_filter_001 = List<DcNotch>.generate(
        channel, (i) => DcNotch());

    adaptive = List<AdaptiveFilterRT>.generate(
        channel, (index) => AdaptiveFilterRT.initialize());

    setDefaultFilterFlag();
  }

  late List<IIRFilterClass> highPass_01;
  late List<IIRFilterClass> highPass_05;
  late List<IIRFilterClass> highPass_005;
  late List<IIRFilterClass> lowPass_40;
  late List<IIRFilterClass> lowPass_100;
  late List<IIRFilterClass> bandStop_50;
  late List<IIRFilterClass> bandStop_60;

  late List<DcNotch> dc_block_filter;
  late List<DcNotch> dc_block_filter_001;

  /// adaptive filters
  late List<AdaptiveFilterRT> adaptive;

  /// fir filter
  // late List<FIRFilter>

  late bool flag_IIR_HPF_01;
  late bool flag_IIR_HPF_005;
  late bool flag_IIR_LPF_40;
  late bool flag_IIR_LPF_100;
  late bool flag_IIR_BSF_50;
  late bool flag_IIR_BSF_60;

  late bool flag_DC_BLOCK;

  /// flag for adaptive filter
  late bool flag_adaptive;

  void setDefaultFilterFlag() {
    /// Dc block
    flag_DC_BLOCK = true;

    /// High pass
    flag_IIR_HPF_01 = true;
    flag_IIR_HPF_005 = false;

    /// Low pass
    flag_IIR_LPF_40 = false;
    flag_IIR_LPF_100 = true;

    /// Band stop
    flag_IIR_BSF_50 = false;
    flag_IIR_BSF_60 = true;

    /// adaptive
    flag_adaptive = false;
  }

  void setFlagDcBlock({bool isDcBlock = true}) {
    flag_DC_BLOCK = isDcBlock;
  }

  void setFlagAdaptive({
    bool flagAdaptiveFilter = false,
  }) {
    flag_adaptive = flagAdaptiveFilter;
  }

  void setFlagHighPass({
    bool isHRF01 = true,
    bool isHRF005 = false,
  }) {
    flag_IIR_HPF_01 = isHRF01;
    flag_IIR_HPF_005 = isHRF005;
  }

  void setFlagLowPass({
    bool isLPF40 = false,
    bool isLPF100 = true,
  }) {
    flag_IIR_LPF_40 = isLPF40;
    flag_IIR_LPF_100 = isLPF100;
  }

  void setFlagBandStop({
    bool isBSF50 = false,
    bool isBSF60 = true,
  }) {
    flag_IIR_BSF_50 = isBSF50;
    flag_IIR_BSF_60 = isBSF60;
  }

  void setFlagEnable(
    String HighPass,
    String LowPass,
    String BandStop,
  ) {
    switch (HighPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_01:
        flag_IIR_HPF_01 = true;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_005:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = true;
        break;
    }
    switch (LowPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_40:
        flag_IIR_LPF_40 = true;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_100:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = true;
        break;
    }

    switch (BandStop) {
      case lib_constants.FILTER_NONE:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_50:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_60:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = true;
        break;
      case lib_constants.FILTER_BAND_STOP_50_60:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = true;
        break;
    }
  }

  double applyFilter(
    int channel,
    double resultData,
    bool leadState,
  ) {
    var filterResultData = resultData;
    if (leadState) {
      if (flag_DC_BLOCK) {
        // filterResultData =
            // dc_block_filter[channel].applyWithDouble(filterResultData);
      }

      if (flag_IIR_HPF_01) {
        filterResultData = highPass_01[channel].apply(filterResultData);
      }
      if (flag_IIR_HPF_005) {
        filterResultData = highPass_005[channel].apply(filterResultData);
      }

      if (flag_IIR_LPF_40) {
        filterResultData = lowPass_40[channel].apply(filterResultData);
      }
      if (flag_IIR_LPF_100) {
        filterResultData = lowPass_100[channel].apply(filterResultData);
      }

      if (flag_IIR_BSF_50) {
        filterResultData = bandStop_50[channel].apply(filterResultData);
      }
      if (flag_IIR_BSF_60) {
        filterResultData = bandStop_60[channel].apply(filterResultData);
      }

      if (flag_adaptive) {
        filterResultData = adaptive[channel].applyFilter(filterResultData);
      }
    }

    return filterResultData;
  }

  bool _isFilterApply() {
    return (flag_IIR_HPF_01 || flag_IIR_HPF_005) ||
        (flag_IIR_LPF_40 || flag_IIR_LPF_100) ||
        (flag_IIR_BSF_50 || flag_IIR_BSF_60);
  }
}
